
#line 3 "dagopts.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer dagopt_create_buffer
#define yy_delete_buffer dagopt_delete_buffer
#define yy_flex_debug dagopt_flex_debug
#define yy_init_buffer dagopt_init_buffer
#define yy_flush_buffer dagopt_flush_buffer
#define yy_load_buffer_state dagopt_load_buffer_state
#define yy_switch_to_buffer dagopt_switch_to_buffer
#define yyin dagoptin
#define yyleng dagoptleng
#define yylex dagoptlex
#define yylineno dagoptlineno
#define yyout dagoptout
#define yyrestart dagoptrestart
#define yytext dagopttext
#define yywrap dagoptwrap
#define yyalloc dagoptalloc
#define yyrealloc dagoptrealloc
#define yyfree dagoptfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE dagoptrestart(dagoptin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int dagoptleng;

extern FILE *dagoptin, *dagoptout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up dagopttext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up dagopttext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via dagoptrestart()), so that the user can continue scanning by
	 * just pointing dagoptin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when dagopttext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int dagoptleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow dagoptwrap()'s to do buffer switches
 * instead of setting up a fresh dagoptin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void dagoptrestart (FILE *input_file  );
void dagopt_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE dagopt_create_buffer (FILE *file,int size  );
void dagopt_delete_buffer (YY_BUFFER_STATE b  );
void dagopt_flush_buffer (YY_BUFFER_STATE b  );
void dagoptpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void dagoptpop_buffer_state (void );

static void dagoptensure_buffer_stack (void );
static void dagopt_load_buffer_state (void );
static void dagopt_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER dagopt_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE dagopt_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE dagopt_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE dagopt_scan_bytes (yyconst char *bytes,int len  );

void *dagoptalloc (yy_size_t  );
void *dagoptrealloc (void *,yy_size_t  );
void dagoptfree (void *  );

#define yy_new_buffer dagopt_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        dagoptensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            dagopt_create_buffer(dagoptin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        dagoptensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            dagopt_create_buffer(dagoptin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *dagoptin = (FILE *) 0, *dagoptout = (FILE *) 0;

typedef int yy_state_type;

extern int dagoptlineno;

int dagoptlineno = 1;

extern char *dagopttext;
#define yytext_ptr dagopttext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up dagopttext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	dagoptleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 200
#define YY_END_OF_BUFFER 201
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[884] =
    {   0,
        0,    0,  201,  198,  199,  200,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,   30,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,   38,   41,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,

      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,   56,  198,  198,  198,  198,  198,  198,
      198,  198,   31,   33,  198,  198,  198,  198,  112,  198,
      198,  198,  198,   79,  198,  198,  198,  198,   10,  198,
      198,  198,  198,  198,  198,  198,  198,  113,  114,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  116,  198,
       29,  118,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  107,  198,  198,  198,
      198,  198,  198,  121,  122,  123,  198,  198,  198,  198,
      198,  198,  105,   36,  198,  198,  198,  198,  198,  198,

      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
       16,   17,  198,  198,  198,  198,  198,  198,   13,   12,
      198,  198,   14,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,    9,   89,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,   37,  198,   80,   81,
       32,  198,  198,  198,  198,  100,   98,  198,  198,  198,
      198,  198,  198,   35,   78,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  109,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,

      198,  183,  198,  198,   11,   83,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,   18,  198,   16,   17,   19,  198,  198,  198,
      132,  133,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  171,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  193,  194,  195,
      198,  198,  198,  198,  198,   84,  198,  198,  198,   60,
       61,  198,  198,  198,  198,  198,  198,  198,   82,  198,

      176,  198,  198,  102,  198,  198,  101,  198,   63,  198,
      198,  198,  141,   71,  198,  198,   21,   23,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,   42,  198,
      198,  117,  198,  198,  110,  198,  198,  198,  186,  198,
      119,  185,  198,  198,  120,  103,  198,  198,  127,  131,
      198,  170,  198,  198,  198,  198,  198,  198,  198,  113,
      198,  198,  198,  198,  198,   18,   20,   19,  198,  198,
      198,  198,  198,  198,  198,  125,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  182,  198,
       96,  198,    8,  198,  198,  196,  197,  198,  198,   58,

      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,   67,  198,  198,  198,  198,  198,
      189,  198,  198,   39,  198,  198,  198,  198,  198,  198,
      142,  198,  198,  198,  198,  151,  198,  144,   95,  150,
      198,  126,  130,  198,  198,  198,  198,  109,  198,   20,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  172,  134,  198,  198,  198,  198,   92,  198,
      145,  198,  198,  198,   57,  198,  198,  198,  198,  198,
       73,  198,  198,   85,  173,  136,  198,  198,  108,  198,

      198,  198,  111,  198,  198,  198,   64,  198,  198,  198,
       68,  198,    1,  198,  198,  115,  198,   43,  198,   53,
      154,  155,  156,  157,  158,  159,  160,  161,  162,  163,
      164,  165,  166,  167,  168,  169,  198,  198,  124,  147,
      198,  198,  198,  198,  198,  198,  198,  198,   26,  198,
      140,  184,  198,  178,  198,  198,  198,  198,  198,  198,
      198,  174,  175,  198,  198,  198,  143,  198,  198,  198,
      198,  198,  198,  198,  198,  190,  198,   74,   75,   72,
       62,  198,  198,  198,  198,  198,  198,  198,  106,  198,
      198,  198,  138,  198,  198,  198,   48,  198,  198,  198,

      198,  198,  198,  198,  187,  198,  152,  198,  149,   93,
      198,  198,  198,  198,   27,   94,  198,  198,  198,  198,
       97,  198,  188,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      104,   65,   66,  198,   69,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  177,   15,
       34,  198,  139,  198,  198,   91,  135,  146,  198,  198,
      198,   76,   90,  198,  153,  198,  198,  198,  198,  198,
      198,   28,   77,  181,  180,  179,  191,  129,  198,  198,
      198,  198,   99,  198,  198,  198,  198,  198,   46,   45,

       47,  198,  198,   54,  198,  198,  198,  198,  198,   86,
      198,  198,  198,  198,  198,  198,  198,  198,   70,  198,
      198,  198,  128,   51,   50,   52,  198,  198,   40,  198,
      198,  192,  198,  198,  198,  198,  198,  198,  198,   59,
      198,  198,  198,  198,  198,  198,  198,   44,   55,  198,
       25,   87,  198,  198,  148,   22,   24,  198,  198,  198,
      198,  198,   49,  198,   88,  198,  198,    6,  198,  198,
      137,    2,  198,    4,    7,    3,  198,  198,  198,  198,
      198,    5,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    4,    4,    1,    5,    6,    7,
        8,    9,   10,   11,   12,   13,   14,   15,    1,    1,
       16,    1,    1,    1,   17,   17,   17,   17,   17,   17,
       18,   17,    1,    1,    1,    1,    1,    1,    1,   19,
        1,    1,   20,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,   21,    1,   22,   23,   24,   25,

       26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
       36,   37,   38,   39,   40,   41,   42,   43,   44,   45,
       46,   47,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[48] =
    {   0,
        1,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[885] =
    {   0,
        0,    0, 1120,    0, 1121, 1121, 1114,   31,   44,   50,
       56,   64,   85,   75,   38,   85,   25,   76,  112,   97,
       27,  103,  119,  141,  130, 1083,  107, 1095,    0,  139,
     1100, 1076, 1073, 1079, 1082, 1085, 1085, 1079, 1078, 1085,
     1084,   41, 1071, 1063, 1056, 1061, 1060, 1067,   36, 1060,
     1074, 1058,   82,  107, 1060, 1087, 1073, 1072, 1070, 1058,
     1051, 1060, 1055, 1082, 1041, 1063, 1054, 1062, 1041, 1048,
      131, 1058, 1051, 1055, 1051, 1054,  123, 1049, 1039, 1038,
       49,  144, 1064, 1031, 1036,  136, 1024, 1042, 1043, 1036,
      166,  170, 1039,   67,  130,  151,  144, 1027, 1027, 1038,

     1017,  164, 1019,  177, 1020, 1029,  152, 1023, 1020,   75,
     1020,  186, 1019, 1032,  185, 1013,  188,  189, 1021, 1011,
      223, 1014, 1043,    0, 1024,  140, 1005, 1015,    0,  999,
     1019, 1009, 1013,    0, 1007,  999,  999, 1002,    0, 1000,
      995,  994, 1007,  999, 1009, 1006, 1003,  213,    0, 1006,
     1003,  996,  205,  988, 1003,  192,  209, 1000, 1001,  985,
        0,    0, 1015,  993,  211,  994,  977, 1000,  991,  989,
      992,  982,  982,  994,  976,  984,    0,  981,  973,  973,
      976,  965,  978,    0,    0,    0,  960,  984,  973,  968,
      212,  964,    0,    0,  216,  210,  235,  203,  224,  234,

      969,  230,  259,  965,  951,  250,  241,  252,  198,  971,
      273,  968,  978,  951,  960,  960,  942,  951,    0,    0,
      951,  945,  943,  960,  955,  950,  243,  953,  943,  945,
      939,  257,  953,    0,  953,  936,  942,  932,  927,  934,
      942,  926,  940,  287,  941,  265,  931,  929,  261,  293,
      926,  937,  925,  927,  913,  931,    0,  923,    0,  931,
        0,  932,  303,  917,  909,    0,    0,  925,  915,  913,
      908,  925,  922,  924,    0,  898,  903,  902,  902,  908,
      903,  927,  930,  895,  893,  895,  892,  910,  915,  244,
      891,  894,  904,  915,  893,  898,  885,  898,  897,  880,

      894,    0,  878,  341,    0,    0,  894,  882,  888,  353,
      893,  888,  874,  879,  895,  894,  876,  875,  881,  364,
      890,  864,  866,  879,  869,  877,  859,  860,  874,  285,
      266,  861,  874,  871,  854,  852,  863,  851,  282,  868,
      850,  283,  864,  880,    0,    0,  862,  852,  848,  850,
        0,    0,  852,  859,  847,  838,  837,  841,  838,  839,
      848,  834,  839,  830,  837,  830,    0,  834,  843,  822,
      835,  823,  837,  846,  820,  818,  820,    0,  847,    0,
      848,  815,  815,  827,  818,    0,  816,  830,  315,    0,
        0,  816,  810,  815,  806,  820,  806,  818,    0,  803,

        0,  803,  815,    0,  829,  811,    0,  804,    0,  802,
      801,  789,    0,    0,  813,  220,    0,    0,  794,  799,
      809,  808,  790,  375,  805,  820,  802,  798,    0,  814,
      797,    0,  795,  795,    0,  804,  779,  796,    0,  781,
        0,    0,  770,  775,    0,    0,  385,  403,    0,    0,
      775,    0,  413,  777,  779,  778,  770,  773,  782,  767,
      784,  781,  767,  769,  775,    0,  777,    0,  778,  777,
      762,  757,  762,  769,  764,    0,  756,  750,  756,  765,
      761,  742,  747,  756,  751,  761,  750,  743,    0,  765,
        0,  423,    0,  740,  763,    0,    0,  749,  750,    0,

      749,  750,  734,  319,  763,  727,  749,  746,  723,  728,
      728,  732,  730,  738,  737,  728,  752,  739,  736,  732,
      733,  721,  299,  728,    0,  724,  712,  718,  718,  725,
        0,  719,  740,    0,  708,  740,  416,  712,  711,  452,
        0,  702,  703,  725,  696,  717,  705,    0,    0,    0,
      698,    0,    0,  720,  714,  698,  687,    0,  711,    0,
      694,  696,  706,  704,  704,  691,  682,  680,  701,  692,
      679,  694,    0,    0,  678,  692,  684,  680,    0,  462,
        0,  699,  453,  675,    0,  674,  686,  670,  705,  704,
        0,  667,  670,    0,    0,    0,  667,  679,    0,  683,

      681,  666,    0,  668,  667,  671,    0,  674,  664,  670,
        0,  658,  673,  670,  671,    0,  650,  669,  667,  667,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  665,  664,    0,    0,
      643,  645,  489,  661,  649,  647,  499,  645,    0,  639,
        0,    0,  656,    0,  644,  660,  649,  635,  640,  631,
      636,    0,    0,  625,  643,  644,    0,  509,  292,  627,
      639,  643,  623,  637,  640,    0,  622,    0,    0,    0,
        0,  624,  614,  303,  624,  632,  620,  629,    0,  326,
      628,  612,    0,  454,  619,  618,  629,  455,  615,  300,

      609,  619,  606,  619,    0,  607,    0,  607,    0,    0,
      601,  608,  614,  519,    0,    0,  609,  602,  612,  595,
        0,  603,    0,  601,  609,  598,  609,  591,  590,  588,
      593,  596,  586,  583,  584,  583,   27,   89,  136,  145,
        0,    0,    0,  222,    0,  294,  327,  312,  314,  306,
      508,  373,  374,  375,  370,  378,  378,  373,    0,    0,
        0,  430,    0,  430,  445,    0,    0,    0,  440,  449,
      467,    0,    0,  455,    0,  512,  507,  513,  511,  515,
      505,    0,    0,    0,    0,    0,    0,    0,  504,  536,
      525,  512,    0,  508,  522,  523,  524,  519,    0,    0,

        0,  529,  529,    0,  531,  515,  531,  528,  533,    0,
      525,  519,  536,  522,  542,  549,  541,  561,    0,  547,
      548,  530,    0,    0,    0,    0,  548,  536,    0,  537,
      545,    0,  539,  539,  555,  541,  535,  548,  578,    0,
      582,  587,  573,  555,  572,  559,  562,    0,    0,  564,
        0,    0,  555,  598,    0,    0,    0,  563,  580,  572,
      574,  572,    0,  574,    0,  576,  578,    0,  588,  568,
        0,    0,  590,  594,    0,    0,  589,  578,  596,  595,
      579,    0, 1121,  620
    } ;

static yyconst flex_int16_t yy_def[885] =
    {   0,
      883,    1,  883,  884,  883,  883,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,    8,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,

      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,    9,  884,  884,  884,  884,  884,

      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,    8,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,

      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,

      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  304,  884,
      884,  310,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  320,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,

      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      424,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  447,  884,  448,  884,  453,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      492,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,

      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  540,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  580,  580,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,

      884,  884,  884,  884,  643,  884,  884,  884,  647,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  668,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  263,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  714,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,

      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  839,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,  884,  884,  884,  884,  884,  884,  884,  884,
      884,  884,    0,  883
    } ;

static yyconst flex_int16_t yy_nxt[1169] =
    {   0,
        4,    5,    6,    4,    4,    7,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    8,    4,
        4,    9,   10,   11,   12,   13,   14,   15,   16,   17,
        4,    4,   18,   19,   20,   21,   22,    4,   23,   24,
       25,   26,   27,   28,    4,    4,    4,   31,   31,   75,
       92,   76,   31,   31,   31,   31,   31,   31,   31,   31,
       67,  145,   45,   68,  137,  786,   32,   33,   34,   93,
       35,  146,   36,   37,  182,  183,   38,   39,   40,   46,
       41,   48,  126,   42,   43,   44,  138,   52,   49,   53,
       57,   50,   58,   54,   51,   47,  239,   77,   63,   78,

      240,   64,   55,   56,   65,   79,   69,  215,  150,   70,
       71,   80,   72,   66,   73,   81,   82,   74,   83,   59,
       88,  151,   60,   61,   94,   62,   89,   95,  120,   29,
      121,   90,   91,   84,  152,  114,   96,   85,   97,   98,
      101,   99,  100,  123,  102,  126,  153,   86,  184,  185,
      103,  115,  170,   87,  171,  116,  124,  177,  216,  263,
      189,  787,  178,  104,  105,  106,  125,  107,  108,  109,
      190,  117,  217,  110,  118,  211,  111,  212,  213,  263,
      218,  112,  127,  219,  788,  235,  113,  195,  236,  196,
      197,  198,  199,  250,  200,  201,  224,  227,  202,  203,

      204,  205,  206,  225,  207,  208,  209,  242,  210,  252,
      228,  243,  229,  230,  247,  291,  231,  232,  282,  244,
      283,  248,  251,  341,  253,  254,  158,  255,  288,  256,
      259,  260,  293,  292,  300,   48,  294,  323,  324,   29,
       60,   61,  342,  789,  301,  328,  524,   63,  329,   29,
       64,  335,  284,   78,  525,  326,   29,  327,   52,  334,
      330,   72,  333,   73,  331,   83,  338,  425,  359,   81,
       82,  336,  103,  332,  337,  105,  360,  426,  107,  343,
       84,  361,  366,   96,  340,  339,  344,  388,   99,  100,
      383,  378,  379,  152,  389,  380,  345,  381,  390,  391,

       87,  367,  227,  252,  384,  462,  385,  401,  401,  401,
      401,  401,  401,  401,  401,  401,  401,  461,  230,  254,
      504,  255,  609,  589,  151,  590,  505,  724,  735,  757,
      725,  742,  743,  790,  791,  736,  758,  792,  610,  793,
      506,  794,  737,  402,  439,  439,  439,  439,  439,  439,
      439,  439,  439,  439,  439,  439,  442,  442,  442,  442,
      442,  442,  442,  442,  442,  442,  442,  442,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  531,
      531,  531,  531,  531,  531,  531,  531,  531,  531,  546,
      546,  546,  546,  546,  546,  546,  546,  546,  546,  799,

      800,  801,  802,  803,  804,  805,  547,  548,  548,  548,
      548,  548,  548,  548,  548,  548,  548,  550,  550,  550,
      550,  550,  550,  550,  550,  550,  550,  581,  581,  581,
      581,  581,  581,  581,  581,  581,  581,  621,  622,  623,
      624,  625,  626,  627,  628,  629,  630,  631,  632,  633,
      634,  635,  636,  806,  807,  637,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  667,  667,  667,  667,
      667,  667,  667,  667,  667,  667,  669,  670,  746,  747,
      752,  753,  671,  808,  754,  748,  809,  810,  811,  672,
      812,  755,  673,  705,  705,  705,  705,  705,  705,  705,

      705,  705,  705,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  723,  723,  723,  723,  723,  723,  723,
      723,  723,  723,  768,  768,  768,  768,  768,  768,  768,
      768,  768,  768,  795,  796,  813,  814,  797,  815,  816,
      817,  818,  819,  820,  798,  821,  822,  823,  824,  825,
      826,  827,  828,  829,  830,  831,  832,  833,  834,  835,
      836,  775,  837,  838,  839,  840,  841,  843,  842,  844,
      846,  847,  848,  849,  850,  851,  845,  852,  853,  775,
      775,  854,  855,  855,  855,  855,  855,  855,  855,  855,
      855,  855,  856,  857,  858,  860,  861,  862,  863,  864,

      865,  859,  775,  866,  867,  868,  869,  870,  871,  872,
      873,  874,  875,  876,  877,  878,  879,  880,  881,  882,
       29,  785,  784,  783,  782,  781,  780,  779,  778,  777,
      776,  775,  775,  774,  773,  772,  771,  770,  769,  767,
      766,  765,  764,  763,  762,  761,  760,  759,  756,  751,
      750,  749,  745,  744,  741,  740,  739,  738,  734,  733,
      732,  731,  730,  729,  728,  727,  726,  722,  721,  720,
      719,  718,  717,  716,  715,  714,  713,  712,  711,  710,
      708,  707,  706,  704,  703,  702,  701,  700,  699,  698,
      697,  696,  695,  694,  693,  692,  691,  690,  689,  688,

      687,  686,  685,  684,  683,  682,  681,  680,  679,  678,
      677,  676,  675,  674,  668,  666,  665,  664,  663,  662,
      661,  660,  659,  658,  657,  656,  655,  654,  653,  652,
      651,  650,  649,  648,  410,  647,  646,  645,   29,  644,
      643,  642,  641,  639,  638,  620,  619,  618,  617,  616,
      615,  614,  613,  612,  611,  608,  607,  606,  605,  604,
      603,  602,  601,  600,  599,  598,  597,  596,  595,  594,
      593,  592,  591,  588,  587,  586,  585,  584,  583,  582,
      580,  579,  578,  577,  576,  575,  574,  573,  572,  571,
      570,  569,  568,  567,  566,  565,  564,  563,  562,  561,

      560,  559,  301,  558,  288,  557,  284,  556,  555,  554,
      553,  552,  551,  549,  545,  544,  543,  542,  541,  540,
      539,  538,  537,  536,  535,  534,  533,  532,  530,  529,
      528,  527,  526,  523,  522,  521,  520,  519,  518,  517,
      516,  515,  514,  513,  512,  511,  510,  509,  508,  507,
      503,  502,  501,  500,  499,  498,  497,  496,  495,  494,
      493,  492,  491,  490,  489,  488,  487,  486,  485,  484,
      483,  482,  481,  480,  479,  478,  477,  476,  475,  474,
      473,  472,  471,  470,  469,  468,  467,  466,  465,  239,
      225,  216,  215,  178,  171,  464,  463,  460,  459,  458,

      137,  457,  456,  455,  454,  453,  451,  450,  449,  448,
      447,  446,  445,  444,  443,   72,  441,  440,  438,  437,
      436,  435,  434,  433,  432,  431,  430,  429,  428,  427,
      424,  423,  422,  421,  420,  419,  418,  417,  416,  415,
      414,  413,  412,  411,  410,  409,  408,  407,  406,  405,
      404,  403,   29,  400,  399,  398,  397,  396,  395,  394,
      393,  392,  387,  386,  382,  377,  376,  375,  374,  373,
      372,  371,  370,  369,  368,  365,  364,  363,  362,  358,
      357,  356,  355,  354,  353,  352,  351,  350,  349,  348,
      347,  346,  120,   93,   89,   76,  325,  322,  321,  320,

      319,  318,  317,  316,  315,  314,  313,  312,  311,  310,
      309,  308,  307,  306,  305,  304,  303,  302,  299,  298,
      297,  296,  295,  290,  289,  287,  286,  285,  281,  280,
      279,  278,  277,  276,  275,  274,  273,  272,  271,  270,
      269,  268,  267,  266,  265,  264,  262,  261,  177,  258,
      257,  249,  246,  245,  241,  238,  237,  234,  233,  226,
      223,  222,  221,  220,  214,  194,  193,  192,  191,  188,
      187,  186,  181,  180,  179,  176,  175,  174,  173,  172,
      169,  168,  167,  166,  165,  164,  163,  162,  161,  160,
      159,  158,  157,  156,  155,  154,  149,  148,  147,  144,

      143,  142,  141,  140,  139,  136,  135,  134,  133,  132,
      131,  130,  129,  128,  127,  126,  122,  119,   30,  883,
        3,  883,  883,  883,  883,  883,  883,  883,  883,  883,
      883,  883,  883,  883,  883,  883,  883,  883,  883,  883,
      883,  883,  883,  883,  883,  883,  883,  883,  883,  883,
      883,  883,  883,  883,  883,  883,  883,  883,  883,  883,
      883,  883,  883,  883,  883,  883,  883,  883
    } ;

static yyconst flex_int16_t yy_chk[1169] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    8,    8,   17,
       21,   17,    8,    8,    8,    8,    8,    8,    8,    8,
       15,   49,   10,   15,   42,  737,    8,    9,    9,   21,
        9,   49,    9,    9,   81,   81,    9,    9,    9,   10,
        9,   11,   94,    9,    9,    9,   42,   12,   11,   12,
       13,   11,   13,   12,   11,   10,  110,   18,   14,   18,

      110,   14,   12,   12,   14,   18,   16,   94,   53,   16,
       16,   18,   16,   14,   16,   18,   18,   16,   19,   13,
       20,   53,   13,   13,   22,   13,   20,   22,   27,  738,
       27,   20,   20,   19,   54,   25,   22,   19,   22,   22,
       23,   22,   22,   30,   23,   95,   54,   19,   82,   82,
       23,   25,   71,   19,   71,   25,   30,   77,   95,  126,
       86,  739,   77,   23,   24,   24,   30,   24,   24,   24,
       86,   25,   96,   24,   25,   92,   24,   92,   92,  126,
       96,   24,   97,   97,  740,  107,   24,   91,  107,   91,
       91,   91,   91,  117,   91,   91,  102,  104,   91,   91,

       91,   91,   91,  102,   91,   91,   91,  112,   91,  118,
      104,  112,  104,  104,  115,  156,  104,  104,  148,  112,
      148,  115,  117,  209,  118,  118,  153,  118,  153,  118,
      121,  121,  157,  156,  165,  196,  157,  191,  191,  195,
      198,  198,  209,  744,  165,  196,  416,  199,  196,  195,
      199,  202,  148,  202,  416,  195,  195,  195,  197,  200,
      197,  200,  199,  200,  197,  203,  207,  290,  227,  202,
      202,  206,  207,  197,  206,  208,  227,  290,  208,  211,
      203,  227,  232,  206,  208,  207,  211,  249,  206,  206,
      246,  244,  244,  331,  249,  244,  211,  244,  250,  250,

      203,  232,  339,  342,  246,  331,  246,  263,  263,  263,
      263,  263,  263,  263,  263,  263,  263,  330,  339,  342,
      389,  342,  523,  504,  330,  504,  389,  669,  684,  700,
      669,  690,  690,  746,  747,  684,  700,  748,  523,  749,
      389,  750,  684,  263,  304,  304,  304,  304,  304,  304,
      304,  304,  304,  304,  304,  304,  310,  310,  310,  310,
      310,  310,  310,  310,  310,  310,  310,  310,  320,  320,
      320,  320,  320,  320,  320,  320,  320,  320,  320,  424,
      424,  424,  424,  424,  424,  424,  424,  424,  424,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447,  752,

      753,  754,  755,  756,  757,  758,  447,  448,  448,  448,
      448,  448,  448,  448,  448,  448,  448,  453,  453,  453,
      453,  453,  453,  453,  453,  453,  453,  492,  492,  492,
      492,  492,  492,  492,  492,  492,  492,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  762,  764,  537,  540,  540,  540,  540,
      540,  540,  540,  540,  540,  540,  580,  580,  580,  580,
      580,  580,  580,  580,  580,  580,  583,  583,  694,  694,
      698,  698,  583,  765,  698,  694,  769,  770,  771,  583,
      774,  698,  583,  643,  643,  643,  643,  643,  643,  643,

      643,  643,  643,  647,  647,  647,  647,  647,  647,  647,
      647,  647,  647,  668,  668,  668,  668,  668,  668,  668,
      668,  668,  668,  714,  714,  714,  714,  714,  714,  714,
      714,  714,  714,  751,  751,  776,  777,  751,  778,  779,
      780,  781,  789,  790,  751,  791,  792,  794,  795,  796,
      797,  798,  802,  803,  805,  806,  807,  808,  809,  811,
      812,  813,  814,  815,  816,  817,  818,  820,  818,  821,
      822,  827,  828,  830,  831,  833,  821,  834,  835,  836,
      837,  838,  839,  839,  839,  839,  839,  839,  839,  839,
      839,  839,  841,  842,  843,  844,  845,  846,  847,  850,

      853,  843,  854,  858,  859,  860,  861,  862,  864,  866,
      867,  869,  870,  873,  874,  877,  878,  879,  880,  881,
      884,  736,  735,  734,  733,  732,  731,  730,  729,  728,
      727,  726,  725,  724,  722,  720,  719,  718,  717,  713,
      712,  711,  708,  706,  704,  703,  702,  701,  699,  697,
      696,  695,  692,  691,  688,  687,  686,  685,  683,  682,
      677,  675,  674,  673,  672,  671,  670,  666,  665,  664,
      661,  660,  659,  658,  657,  656,  655,  653,  650,  648,
      646,  645,  644,  642,  641,  638,  637,  620,  619,  618,
      617,  615,  614,  613,  612,  610,  609,  608,  606,  605,

      604,  602,  601,  600,  598,  597,  593,  592,  590,  589,
      588,  587,  586,  584,  582,  578,  577,  576,  575,  572,
      571,  570,  569,  568,  567,  566,  565,  564,  563,  562,
      561,  559,  557,  556,  555,  554,  551,  547,  546,  545,
      544,  543,  542,  539,  538,  536,  535,  533,  532,  530,
      529,  528,  527,  526,  524,  522,  521,  520,  519,  518,
      517,  516,  515,  514,  513,  512,  511,  510,  509,  508,
      507,  506,  505,  503,  502,  501,  499,  498,  495,  494,
      490,  488,  487,  486,  485,  484,  483,  482,  481,  480,
      479,  478,  477,  475,  474,  473,  472,  471,  470,  469,

      467,  465,  464,  463,  462,  461,  460,  459,  458,  457,
      456,  455,  454,  451,  444,  443,  440,  438,  437,  436,
      434,  433,  431,  430,  428,  427,  426,  425,  423,  422,
      421,  420,  419,  415,  412,  411,  410,  408,  406,  405,
      403,  402,  400,  398,  397,  396,  395,  394,  393,  392,
      388,  387,  385,  384,  383,  382,  381,  379,  377,  376,
      375,  374,  373,  372,  371,  370,  369,  368,  366,  365,
      364,  363,  362,  361,  360,  359,  358,  357,  356,  355,
      354,  353,  350,  349,  348,  347,  344,  343,  341,  340,
      338,  337,  336,  335,  334,  333,  332,  329,  328,  327,

      326,  325,  324,  323,  322,  321,  319,  318,  317,  316,
      315,  314,  313,  312,  311,  309,  308,  307,  303,  301,
      300,  299,  298,  297,  296,  295,  294,  293,  292,  291,
      289,  288,  287,  286,  285,  284,  283,  282,  281,  280,
      279,  278,  277,  276,  274,  273,  272,  271,  270,  269,
      268,  265,  264,  262,  260,  258,  256,  255,  254,  253,
      252,  251,  248,  247,  245,  243,  242,  241,  240,  239,
      238,  237,  236,  235,  233,  231,  230,  229,  228,  226,
      225,  224,  223,  222,  221,  218,  217,  216,  215,  214,
      213,  212,  210,  205,  204,  201,  192,  190,  189,  188,

      187,  183,  182,  181,  180,  179,  178,  176,  175,  174,
      173,  172,  171,  170,  169,  168,  167,  166,  164,  163,
      160,  159,  158,  155,  154,  152,  151,  150,  147,  146,
      145,  144,  143,  142,  141,  140,  138,  137,  136,  135,
      133,  132,  131,  130,  128,  127,  125,  123,  122,  120,
      119,  116,  114,  113,  111,  109,  108,  106,  105,  103,
      101,  100,   99,   98,   93,   90,   89,   88,   87,   85,
       84,   83,   80,   79,   78,   76,   75,   74,   73,   72,
       70,   69,   68,   67,   66,   65,   64,   63,   62,   61,
       60,   59,   58,   57,   56,   55,   52,   51,   50,   48,

       47,   46,   45,   44,   43,   41,   40,   39,   38,   37,
       36,   35,   34,   33,   32,   31,   28,   26,    7,    3,
      883,  883,  883,  883,  883,  883,  883,  883,  883,  883,
      883,  883,  883,  883,  883,  883,  883,  883,  883,  883,
      883,  883,  883,  883,  883,  883,  883,  883,  883,  883,
      883,  883,  883,  883,  883,  883,  883,  883,  883,  883,
      883,  883,  883,  883,  883,  883,  883,  883
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int dagopt_flex_debug;
int dagopt_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *dagopttext;
#line 1 "dagopts.l"
/*
 * Copyright (c) 2003 Endace Technology Ltd, Hamilton, New Zealand.
 * All rights reserved.
 *
 * This source code is proprietary to Endace Technology Ltd and no part
 * of it may be redistributed, published or disclosed except as outlined
 * in the written contract supplied with this product.
 *
 * $Id: dagopts.l 13608 2010-12-29 08:32:27Z karthik.sharma $
 */
#define YY_NO_INPUT 1
#line 14 "dagopts.l"

#include "dagtoken.h"
#ifdef _WIN32
#include <stdlib.h>
#endif

#define yylval dagoptlval
#define yylvalfl dagoptlvalfl

int yylval;
double yylvalfl;

#line 1047 "dagopts.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int dagoptlex_destroy (void );

int dagoptget_debug (void );

void dagoptset_debug (int debug_flag  );

YY_EXTRA_TYPE dagoptget_extra (void );

void dagoptset_extra (YY_EXTRA_TYPE user_defined  );

FILE *dagoptget_in (void );

void dagoptset_in  (FILE * in_str  );

FILE *dagoptget_out (void );

void dagoptset_out  (FILE * out_str  );

int dagoptget_leng (void );

char *dagoptget_text (void );

int dagoptget_lineno (void );

void dagoptset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int dagoptwrap (void );
#else
extern int dagoptwrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( dagopttext, dagoptleng, 1, dagoptout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( dagoptin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( dagoptin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, dagoptin))==0 && ferror(dagoptin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(dagoptin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int dagoptlex (void);

#define YY_DECL int dagoptlex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after dagopttext and dagoptleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 30 "dagopts.l"


	yylval = 0; /* do this for every token not using yylval, to be on the safe side */

#line 1237 "dagopts.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! dagoptin )
			dagoptin = stdin;

		if ( ! dagoptout )
			dagoptout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			dagoptensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				dagopt_create_buffer(dagoptin,YY_BUF_SIZE );
		}

		dagopt_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of dagopttext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 884 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1121 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 34 "dagopts.l"
{ return T_DEFAULT; }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 35 "dagopts.l"
{ return T_DEFAULT_DS3_ATM; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 36 "dagopts.l"
{ return T_DEFAULT_DS3_HDLC; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 37 "dagopts.l"
{ return T_DEFAULT_E3_HDLC; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 38 "dagopts.l"
{ return T_DEFAULT_E3_HDLC_FRACT; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 39 "dagopts.l"
{ return T_DEFAULT_E3_ATM; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 40 "dagopts.l"
{ return T_DEFAULT_KENTROX; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 41 "dagopts.l"
{ return T_SONET; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 42 "dagopts.l"
{ return T_SDH; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 43 "dagopts.l"
{ return T_ATM; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 44 "dagopts.l"
{ return T_HDLC; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 45 "dagopts.l"
{ return T_PPP; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 46 "dagopts.l"
{ return T_POS; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 47 "dagopts.l"
{ return T_RAW; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 48 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_SUPPRESS_ERROR; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 49 "dagopts.l"
{ return T_LINK_OC1; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 50 "dagopts.l"
{ return T_LINK_OC3; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 51 "dagopts.l"
{ return T_LINK_OC12; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 52 "dagopts.l"
{ return T_LINK_OC48; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 53 "dagopts.l"
{ return T_LINK_OC192; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 54 "dagopts.l"
{ return T_POS_CRC16; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 55 "dagopts.l"
{ return T_TERF_STRIP_16; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 56 "dagopts.l"
{ return T_POS_CRC32; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 57 "dagopts.l"
{ return T_TERF_STRIP_32; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 58 "dagopts.l"
{ return T_TERF_NOSTRIP; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 59 "dagopts.l"
{ return T_TR_TERF_NO_DELAY;}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 60 "dagopts.l"
{ return T_TR_TERF_RELATIVE;}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 61 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_TR_TERF_RX_ERROR; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 62 "dagopts.l"
{ yylval = 0 ; return T_ETH; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 63 "dagopts.l"
{ return T_ETH_10; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 64 "dagopts.l"
{ return T_ETH_100; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 65 "dagopts.l"
{ return T_ETH_1000; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 66 "dagopts.l"
{ return T_ETH_10G;}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 67 "dagopts.l"
{ return T_ETH_1000_STATUS; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 68 "dagopts.l"
{ yylval = 1 ; return T_ETH_AUTO; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 69 "dagopts.l"
{ return T_SAR_NNI; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 70 "dagopts.l"
{ return T_SAR_UNI; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 71 "dagopts.l"
{ return T_LINK_E1; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 72 "dagopts.l"
{ return T_LINK_E1_CRC; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 73 "dagopts.l"
{ return T_LINK_E1_UNFRAMED; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 74 "dagopts.l"
{ return T_LINK_E3; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 75 "dagopts.l"
{ return T_LINK_E3_CC; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 76 "dagopts.l"
{ return T_LINK_DS3_M23; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 77 "dagopts.l"
{ return T_LINK_DS3_M23_PLCP; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 78 "dagopts.l"
{ return T_LINK_DS3_M23_FF; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 79 "dagopts.l"
{ return T_LINK_DS3_M23_EF; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 80 "dagopts.l"
{ return T_LINK_DS3_M23_IF; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 81 "dagopts.l"
{ return T_LINK_DS3_CBIT; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 82 "dagopts.l"
{ return T_LINK_DS3_CBIT_PLCP; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 83 "dagopts.l"
{ return T_LINK_DS3_CBIT_FF; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 84 "dagopts.l"
{ return T_LINK_DS3_CBIT_EF; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 85 "dagopts.l"
{ return T_LINK_DS3_CBIT_IF; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 86 "dagopts.l"
{ return T_LINK_E3_G751; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 87 "dagopts.l"
{ return T_LINK_E3_G751_IF; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 88 "dagopts.l"
{ return T_LINK_E3_G751_PLCP; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 89 "dagopts.l"
{ return T_LINK_T1; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 90 "dagopts.l"
{ return T_LINK_T1_ESF; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 91 "dagopts.l"
{ return T_LINK_T1_SF; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 92 "dagopts.l"
{ return T_LINK_T1_UNFRAMED; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 93 "dagopts.l"
{ return T_LINK_TU11; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 94 "dagopts.l"
{ return T_LINK_TU12; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 95 "dagopts.l"
{ return T_LINK_TUNOMAP; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 96 "dagopts.l"
{ return T_LINK_ASYNC1; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 97 "dagopts.l"
{ return T_LINK_BIT_SYNC; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 98 "dagopts.l"
{ return T_LINK_BYTE_SYNC1; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 99 "dagopts.l"
{ return T_LINK_BYTE_SYNC2; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 100 "dagopts.l"
{ yylval = 1; return T_LINK_CORE_ON; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 101 "dagopts.l"
{ return T_LINK_CORE_ON; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 102 "dagopts.l"
{ return T_DUCK_SET_TO_HOST; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 103 "dagopts.l"
{ return T_DUCK_SET_TO_HOST; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 104 "dagopts.l"
{ return T_LINK_CLEAR; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 105 "dagopts.l"
{ return T_LINK_TERMEXT; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 106 "dagopts.l"
{ return T_LINK_TERM75; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 107 "dagopts.l"
{ return T_LINK_TERM100; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 108 "dagopts.l"
{ return T_LINK_TERM120; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 109 "dagopts.l"
{ return T_LINK_RX_TERMEXT; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 110 "dagopts.l"
{ return T_LINK_TX_TERMEXT; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 111 "dagopts.l"
{ return T_LINK_B8ZS; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 112 "dagopts.l"
{ return T_LINK_AMI; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 113 "dagopts.l"
{ return T_LINK_VC3; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 114 "dagopts.l"
{ return T_LINK_VC4; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 115 "dagopts.l"
{ return T_LINK_VC4C; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 116 "dagopts.l"
{ return T_TIMESTAMP_HEAD; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 117 "dagopts.l"
{ return T_TIMESTAMP_TAIL; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 118 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_TX_CRC; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 119 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_RX_MONITOR_MODE; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 120 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_RX_EQUALIZER; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 121 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_REDUNDANCY_CONTROL; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 122 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_SFM; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 123 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_SFM_CLOCK; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 124 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_PDH_GLOBAL; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 125 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_SFPPWR; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 126 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_CORE_ON; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 127 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_RKTIOPWR; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 128 "dagopts.l"
{ return (dagopttext[0]!='n') ? T_MASTER : T_SLAVE; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 129 "dagopts.l"
{ return (dagopttext[0]!='n') ? T_SLAVE  : T_MASTER; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 130 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_SONET_SCRAMBLE; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 131 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_ATM_ADD_HEC; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 132 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_ATM_DESCRAMBLE; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 133 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_ATM_FIX_HEC; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 134 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_ATM_PASS_HEC; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 135 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_ATM_PASS_IDLE; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 136 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_ATM_LCELL; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 137 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_ATM_PLOAD_SCRAMBLE; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 138 "dagopts.l"
{ yylval = (dagopttext[1]!='o') ; return T_ETH_AUTO; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 139 "dagopts.l"
{ yylval = (dagopttext[1]!='o') ; return T_ETH_AUTO; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 140 "dagopts.l"
{ yylval = (dagopttext[0]!='l') ; return T_ETH_WAN; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 141 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_GPP_VARLEN; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 142 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_PBM_DROP; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 143 "dagopts.l"
{ yylval = 0 ; return T_GPP_VARLEN; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 144 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_GPP_ALIGN64; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 145 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_ADM; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 146 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_CRC; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 147 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_DCR; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 148 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_DISCARD; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 149 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_EQL; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 150 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_D37D_FRAMER_LOOPBACK; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 151 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_FCL; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 152 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_HGAIN; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 153 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_LASER; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 154 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_LT0; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 155 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_LT1; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 156 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_M23; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 157 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_FF_00_DEL; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 158 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_RESET; }
	YY_BREAK
case 126:
#line 160 "dagopts.l"
case 127:
YY_RULE_SETUP
#line 160 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_LSEQL; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 161 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_DIGITAL_LOS; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 162 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_ANALOG_LOS; }
	YY_BREAK
case 130:
#line 164 "dagopts.l"
case 131:
YY_RULE_SETUP
#line 164 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_LINK_LSFCL; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 165 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_POS_MAXCHECK; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 166 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_POS_MINCHECK; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 167 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_POS_RXPKTS; }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 168 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_POS_SCRAMBLE; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 169 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_POS_TXPKTS; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 170 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_HEC_CORRECTION; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 171 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_POS_CRCSTRIP; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 172 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_INTERFACE_SWAP; }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 173 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_PBM_OVERLAP; }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 174 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_SAR_CELLS; }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 175 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_SAR_FRAMES; }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 176 "dagopts.l"
{ yylval = strtoul(&dagopttext[6], NULL, 0) ; return T_POS_MINLEN; }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 177 "dagopts.l"
{ yylval = strtoul(&dagopttext[5], NULL, 0) ; return T_POS_MAXLEN; }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 178 "dagopts.l"
{ yylval = strtoul(&dagopttext[5], NULL, 0) ; return T_GPP_SLEN; }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 179 "dagopts.l"
{ yylval = strtoul(&dagopttext[8], NULL, 0) ; return T_RAW_SLEN; }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 180 "dagopts.l"
{ yylval = strtoul(&dagopttext[6], NULL, 0) ; return T_LINK_E3_HDLC_FRACT; }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 181 "dagopts.l"
{ yylval = strtoul(&dagopttext[11], NULL, 0) ; return T_DUCK_SYNC_THRESH; }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 182 "dagopts.l"
{ yylval = strtoul(&dagopttext[7], NULL, 0) ; return T_ATM_NCELLS; }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 183 "dagopts.l"
{ yylval = strtoul(&dagopttext[5], NULL, 0) ; return T_LINK_MODE; }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 184 "dagopts.l"
{ yylval = strtoul(&dagopttext[5], NULL, 0) ; return T_LINK_WHICH; }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 185 "dagopts.l"
{ yylval = 0xffff ; return T_LINK_WHICH; }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 186 "dagopts.l"
{ yylval = 0; return T_STEER; }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 187 "dagopts.l"
{ yylval = (dagopttext[0]!='d') ; return T_GPP_ENABLE_A; }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 188 "dagopts.l"
{ yylval = (dagopttext[0]!='d') ; return T_GPP_ENABLE_B; }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 189 "dagopts.l"
{ yylval = (dagopttext[0]!='d') ; return T_GPP_ENABLE_C; }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 190 "dagopts.l"
{ yylval = (dagopttext[0]!='d') ; return T_GPP_ENABLE_D; }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 191 "dagopts.l"
{ yylval = (dagopttext[0]!='d') ; return T_GPP_ENABLE_E; }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 192 "dagopts.l"
{ yylval = (dagopttext[0]!='d') ; return T_GPP_ENABLE_F; }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 193 "dagopts.l"
{ yylval = (dagopttext[0]!='d') ; return T_GPP_ENABLE_G; }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 194 "dagopts.l"
{ yylval = (dagopttext[0]!='d') ; return T_GPP_ENABLE_H; }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 195 "dagopts.l"
{ yylval = (dagopttext[0]!='d') ; return T_GPP_ENABLE_I; }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 196 "dagopts.l"
{ yylval = (dagopttext[0]!='d') ; return T_GPP_ENABLE_J; }
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 197 "dagopts.l"
{ yylval = (dagopttext[0]!='d') ; return T_GPP_ENABLE_K; }
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 198 "dagopts.l"
{ yylval = (dagopttext[0]!='d') ; return T_GPP_ENABLE_L; }
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 199 "dagopts.l"
{ yylval = (dagopttext[0]!='d') ; return T_GPP_ENABLE_M; }
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 200 "dagopts.l"
{ yylval = (dagopttext[0]!='d') ; return T_GPP_ENABLE_N; }
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 201 "dagopts.l"
{ yylval = (dagopttext[0]!='d') ; return T_GPP_ENABLE_O; }
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 202 "dagopts.l"
{ yylval = (dagopttext[0]!='d') ; return T_GPP_ENABLE_P; }
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 203 "dagopts.l"
{ yylval = 0; return T_PBM_MEMCONFIG; }
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 204 "dagopts.l"
{ return T_PBM_RXTX; }
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 205 "dagopts.l"
{ return T_PBM_RXONLY; }
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 206 "dagopts.l"
{ return T_PBM_TXONLY; }
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 207 "dagopts.l"
{ return T_MUX_RXMERGE; }
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 208 "dagopts.l"
{ return T_MUX_RXSPLIT; }
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 209 "dagopts.l"
{ yylval = 0; return T_MUX_CONFIG; }
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 210 "dagopts.l"
{ yylval = (dagopttext[0]!='d') ; return T_SAR_ENABLE; }
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 211 "dagopts.l"
{ yylval = (dagopttext[0]!='n') ; return T_ETH_PROMISC;}
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 212 "dagopts.l"
{return T_ETH_10GBASESR; }
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 213 "dagopts.l"
{return T_ETH_10GBASELR; }
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 214 "dagopts.l"
{return T_ETH_10GBASEER; }
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 215 "dagopts.l"
{return T_ETH_SGMII; }
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 216 "dagopts.l"
{return T_ETH_GBIC; }
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 217 "dagopts.l"
{ yylval = (dagopttext[0]!='n'); return T_SAR_PATH_OAM; }         
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 218 "dagopts.l"
{ yylval = 0; return T_HLB_RANGE; }
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 219 "dagopts.l"
{ yylval = 0; return T_HAT_RANGE; }
	YY_BREAK
case 187:
YY_RULE_SETUP
#line 220 "dagopts.l"
{ yylval = strtoul(&dagopttext[7], NULL, 0) ; return T_IDELAY; }
	YY_BREAK
case 188:
YY_RULE_SETUP
#line 221 "dagopts.l"

	YY_BREAK
case 189:
YY_RULE_SETUP
#line 222 "dagopts.l"

	YY_BREAK
case 190:
YY_RULE_SETUP
#line 223 "dagopts.l"
{ return T_INFINIBAND_TAPMODE;}
	YY_BREAK
case 191:
YY_RULE_SETUP
#line 224 "dagopts.l"
{ return T_INFINIBAND_ACTIVEMODE;}
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 225 "dagopts.l"
{ return T_INFINIBAND_MONITORMODE;}
	YY_BREAK
case 193:
YY_RULE_SETUP
#line 226 "dagopts.l"
{ return T_LINK_STM0; }
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 227 "dagopts.l"
{ return T_LINK_STM1; }
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 228 "dagopts.l"
{ return T_LINK_STM4; }
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 229 "dagopts.l"
{ return T_LINK_STM16; }
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 230 "dagopts.l"
{ return T_LINK_STM64; }
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 231 "dagopts.l"
{ return T_ERROR; }
	YY_BREAK
case 199:
YY_RULE_SETUP
#line 232 "dagopts.l"

	YY_BREAK
case 200:
YY_RULE_SETUP
#line 233 "dagopts.l"
ECHO;
	YY_BREAK
#line 2314 "dagopts.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed dagoptin at a new source and called
			 * dagoptlex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = dagoptin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( dagoptwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * dagopttext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of dagoptlex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					dagoptrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			dagoptrestart(dagoptin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) dagoptrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 884 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 884 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 883);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					dagoptrestart(dagoptin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( dagoptwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve dagopttext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void dagoptrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        dagoptensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            dagopt_create_buffer(dagoptin,YY_BUF_SIZE );
	}

	dagopt_init_buffer(YY_CURRENT_BUFFER,input_file );
	dagopt_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void dagopt_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		dagoptpop_buffer_state();
	 *		dagoptpush_buffer_state(new_buffer);
     */
	dagoptensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	dagopt_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (dagoptwrap()) processing, but the only time this flag
	 * is looked at is after dagoptwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void dagopt_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	dagoptin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE dagopt_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) dagoptalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in dagopt_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) dagoptalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in dagopt_create_buffer()" );

	b->yy_is_our_buffer = 1;

	dagopt_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with dagopt_create_buffer()
 * 
 */
    void dagopt_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		dagoptfree((void *) b->yy_ch_buf  );

	dagoptfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a dagoptrestart() or at EOF.
 */
    static void dagopt_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	dagopt_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then dagopt_init_buffer was _probably_
     * called from dagoptrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void dagopt_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		dagopt_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void dagoptpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	dagoptensure_buffer_stack();

	/* This block is copied from dagopt_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from dagopt_switch_to_buffer. */
	dagopt_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void dagoptpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	dagopt_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		dagopt_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void dagoptensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)dagoptalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in dagoptensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)dagoptrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in dagoptensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE dagopt_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) dagoptalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in dagopt_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	dagopt_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to dagoptlex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       dagopt_scan_bytes() instead.
 */
YY_BUFFER_STATE dagopt_scan_string (yyconst char * yystr )
{
    
	return dagopt_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to dagoptlex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE dagopt_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) dagoptalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in dagopt_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = dagopt_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in dagopt_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up dagopttext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		dagopttext[dagoptleng] = (yy_hold_char); \
		(yy_c_buf_p) = dagopttext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		dagoptleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int dagoptget_lineno  (void)
{
        
    return dagoptlineno;
}

/** Get the input stream.
 * 
 */
FILE *dagoptget_in  (void)
{
        return dagoptin;
}

/** Get the output stream.
 * 
 */
FILE *dagoptget_out  (void)
{
        return dagoptout;
}

/** Get the length of the current token.
 * 
 */
int dagoptget_leng  (void)
{
        return dagoptleng;
}

/** Get the current token.
 * 
 */

char *dagoptget_text  (void)
{
        return dagopttext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void dagoptset_lineno (int  line_number )
{
    
    dagoptlineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see dagopt_switch_to_buffer
 */
void dagoptset_in (FILE *  in_str )
{
        dagoptin = in_str ;
}

void dagoptset_out (FILE *  out_str )
{
        dagoptout = out_str ;
}

int dagoptget_debug  (void)
{
        return dagopt_flex_debug;
}

void dagoptset_debug (int  bdebug )
{
        dagopt_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from dagoptlex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    dagoptin = stdin;
    dagoptout = stdout;
#else
    dagoptin = (FILE *) 0;
    dagoptout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * dagoptlex_init()
     */
    return 0;
}

/* dagoptlex_destroy is for both reentrant and non-reentrant scanners. */
int dagoptlex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		dagopt_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		dagoptpop_buffer_state();
	}

	/* Destroy the stack itself. */
	dagoptfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * dagoptlex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *dagoptalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *dagoptrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void dagoptfree (void * ptr )
{
	free( (char *) ptr );	/* see dagoptrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 233 "dagopts.l"



/*
 * Also define a dagoptwrap.  Note that if we're using flex, it will
 * define a macro to map this identifier to dagoptwrap.
 */
int
dagoptwrap(void)
{
	return 1;
}

